@@ -1,3 +1,22 @@
+"""
+Copyright (c) 2022 Poutyne and all respective contributors.
+
+Each contributor holds copyright over their respective contributions. The project versioning (Git)
+records all such contribution source information.
+
+This file is part of Poutyne.
+
+Poutyne is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General Public
+License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later
+version.
+
+Poutyne is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
+of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.
+
+You should have received a copy of the GNU Lesser General Public License along with Poutyne. If not, see
+<https://www.gnu.org/licenses/>.
+"""
+
 # Because of the way the callbacks are generated, we have to disable linting here.
 # pylint: disable=no-name-in-module
 import os
@@ -34,22 +53,18 @@ class OptimizerCheckpointTest(TestCase):
         valid_gen = some_data_generator(OptimizerCheckpointTest.batch_size)
         lr_scheduler = ExponentialLR(gamma=0.01)
         checkpointer = LRSchedulerCheckpoint(lr_scheduler, self.checkpoint_filename, period=1)
-        self.model.fit_generator(train_gen,
-                                 valid_gen,
-                                 epochs=OptimizerCheckpointTest.epochs,
-                                 steps_per_epoch=5,
-                                 callbacks=[checkpointer])
+        self.model.fit_generator(
+            train_gen, valid_gen, epochs=OptimizerCheckpointTest.epochs, steps_per_epoch=5, callbacks=[checkpointer]
+        )
 
     def test_reduce_lr_on_plateau_integration(self):
         train_gen = some_data_generator(OptimizerCheckpointTest.batch_size)
         valid_gen = some_data_generator(OptimizerCheckpointTest.batch_size)
         reduce_lr = ReduceLROnPlateau(monitor='loss', patience=3)
         checkpointer = LRSchedulerCheckpoint(reduce_lr, self.checkpoint_filename, period=1)
-        self.model.fit_generator(train_gen,
-                                 valid_gen,
-                                 epochs=OptimizerCheckpointTest.epochs,
-                                 steps_per_epoch=5,
-                                 callbacks=[checkpointer])
+        self.model.fit_generator(
+            train_gen, valid_gen, epochs=OptimizerCheckpointTest.epochs, steps_per_epoch=5, callbacks=[checkpointer]
+        )
 
     def test_any_scheduler_checkpoints(self):
         lr_scheduler = ExponentialLR(gamma=0.01)
